#!/bin/bash
#set -x

# Install ActiveMQ, JDK, PostgreSQL, and Tomcat

#Versions
VSN_ACTIVEMQ=5.15.6
VSN_JDK=8.31.0.1-jdk8.0.181
VSN_POSTGRESQL=10.5-2
VSN_POSTGRESQL_SERVICE=10
VSN_TOMCAT=9.0.12

#Passwords
SCRT_POSTGRES=n0v3ll

#Ports
PORT_POSTGRES=5432

#Names
NAME_ACTIVEMQ=activemq
NAME_NOVLUA=novlua
NAME_POSTGRES=postgres
NAME_TOMCAT=tomcat

#Directories
DIR_ACTIVEMQ=${NAME_ACTIVEMQ}
DIR_BACKUP=backup
DIR_BASE=/opt/netiq/idm/apps
DIR_COMPRESSED=./compressed
DIR_JDK=jdk
DIR_LOG=./logs
DIR_POSTGRES=${NAME_POSTGRES}
DIR_POSTGRES_DATA=data
DIR_SERVICE=/usr/lib/systemd/system
DIR_TOMCAT=${NAME_TOMCAT}

#Files
FILE_ACTIVEMQ=${DIR_COMPRESSED}/apache-activemq-${VSN_ACTIVEMQ}-bin.tar.gz
FILE_INDEX=index.html
FILE_JDK=${DIR_COMPRESSED}/zulu${VSN_JDK}-linux_x64.tar.gz
FILE_LOG=${DIR_LOG}/IDGov35-Core-Helper-All.log
FILE_POSTGRESQL=${DIR_COMPRESSED}/postgresql-${VSN_POSTGRESQL}-linux-x64.run
FILE_TOMCAT=${DIR_COMPRESSED}/apache-tomcat-${VSN_TOMCAT}.tar.gz

#Services
SERV_ACTIVEMQ_SERVICE=identity_activemq
SERV_TOMCAT_SERVICE=identity_tomcat


#Tee
TEE="tee -a"

#Start the Installation
mkdir -p ${DIR_LOG} >> /dev/null 2>&1
>${FILE_LOG}

cp ./untouched/activemq.service ./${SERV_ACTIVEMQ_SERVICE}.service
cp ./untouched/tomcat.service ./${SERV_TOMCAT_SERVICE}.service
cp ./untouched/index.html ./index.html

echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Setting Base Directory of: " ${DIR_BASE} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE} 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Extracting ActiveMQ to: " ${DIR_BASE}/${DIR_ACTIVEMQ} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE}/${DIR_ACTIVEMQ} 2>&1 | ${TEE} ${FILE_LOG}
tar -xvf ${FILE_ACTIVEMQ} -C ${DIR_BASE}/${DIR_ACTIVEMQ} --strip-components=1 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Extracting JDK to: " ${DIR_BASE}/${DIR_JDK} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE}/${DIR_JDK} 2>&1 | ${TEE} ${FILE_LOG}
tar -xvf ${FILE_JDK} -C ${DIR_BASE}/${DIR_JDK} --strip-components=1 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Creating symbolic link to: " ${DIR_BASE}/jre 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
ln -s ${DIR_BASE}/${DIR_JDK}/jre ${DIR_BASE}/jre 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Installing PostgreSQL to: " ${DIR_BASE}/${DIR_POSTGRES} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
chmod +x ./${FILE_POSTGRESQL} 2>&1 | ${TEE} ${FILE_LOG}
./${FILE_POSTGRESQL} --unattendedmodeui none --mode unattended --superaccount ${NAME_POSTGRES} --superpassword ${SCRT_POSTGRES} --serverport ${PORT_POSTGRES} --prefix ${DIR_BASE}/${DIR_POSTGRES} --datadir ${DIR_BASE}/${DIR_POSTGRES}/${DIR_POSTGRES_DATA} 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Updating PostgreSQL to allow remote access " 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|/32|/0 |g" ${DIR_BASE}/${DIR_POSTGRES}/${DIR_POSTGRES_DATA}/pg_hba.conf 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Restarting PostgreSQL " 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
systemctl restart postgresql-${VSN_POSTGRESQL_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Extracting Tomcat to: " ${DIR_BASE}/${DIR_TOMCAT} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE}/${DIR_TOMCAT} 2>&1 | ${TEE} ${FILE_LOG}
tar -xvf ${FILE_TOMCAT} -C ${DIR_BASE}/${DIR_TOMCAT} --strip-components=1 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Copying the ActiveMQ Jar to: " ${DIR_BASE}/${DIR_TOMCAT}/lib 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
cp ${DIR_BASE}/${DIR_ACTIVEMQ}/${DIR_ACTIVEMQ}-all*.jar ${DIR_BASE}/${DIR_TOMCAT}/lib 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Moving the default Tomcat wars to: " ${DIR_BASE}/${DIR_BACKUP} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE}/${DIR_BACKUP} 2>&1 | ${TEE} ${FILE_LOG}
mv ${DIR_BASE}/${DIR_TOMCAT}/webapps/* ${DIR_BASE}/${DIR_BACKUP} 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Creating new default Tomcat index file in: " ${DIR_BASE}/${DIR_TOMCAT}/webapps/ROOT 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
mkdir -p ${DIR_BASE}/${DIR_TOMCAT}/webapps/ROOT 2>&1 | ${TEE} ${FILE_LOG}
mv ${FILE_INDEX} ${DIR_BASE}/${DIR_TOMCAT}/webapps/ROOT/ 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Create Tomcat user and group: " ${NAME_NOVLUA} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
groupadd ${NAME_NOVLUA} -r 2>&1 | ${TEE} ${FILE_LOG}
useradd ${NAME_NOVLUA} -r -m -c "User created by convenience script" -s /bin/bash -d ${DIR_BASE}/${NAME_NOVLUA} -g ${NAME_NOVLUA} 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Recursively assign directory ownerships: " ${NAME_NOVLUA} 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
/bin/chown -R ${NAME_NOVLUA}.${NAME_NOVLUA} ${DIR_BASE}/${DIR_TOMCAT} 2>&1 | ${TEE} ${FILE_LOG}
/bin/chown -R ${NAME_NOVLUA}.users ${DIR_BASE}/${DIR_ACTIVEMQ} 2>&1 | ${TEE} ${FILE_LOG}
/bin/chown -R ${NAME_NOVLUA}.users ${DIR_BASE}/${DIR_JDK} 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Prepare ActiveMQ service: " ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_INSTALL_BASE|${DIR_BASE}|g" ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_INSTALL_JAVA|${DIR_BASE}/${DIR_JDK}|g" ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_TOMCAT_USER|${NAME_NOVLUA}|g" ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_VERSION_ACTIVEMQ|${VSN_ACTIVEMQ}|g" ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
mv ${SERV_ACTIVEMQ_SERVICE}.service ${DIR_SERVICE}/${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
systemctl enable ${SERV_ACTIVEMQ_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e " Prepare Tomcat service: " ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_INSTALL_TOMCAT|${DIR_BASE}/${DIR_TOMCAT}|g" ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_INSTALL_JAVA|${DIR_BASE}/${DIR_JDK}|g" ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_VERSION_TOMCAT|${VSN_TOMCAT}|g" ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_TOMCAT_USER|${NAME_NOVLUA}|g" ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
sed -i "s|REPLACE_SERVICE_ACTIVEMQ|${SERV_ACTIVEMQ_SERVICE}|g" ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
mv ${SERV_TOMCAT_SERVICE}.service ${DIR_SERVICE}/${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}
systemctl enable ${SERV_TOMCAT_SERVICE}.service 2>&1 | ${TEE} ${FILE_LOG}


echo -e "\n" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "Completed" 2>&1 | ${TEE} ${FILE_LOG}
echo -e "Review the log file: ${FILE_LOG} " 2>&1 | ${TEE} ${FILE_LOG}
echo -e "######################################################################################" 2>&1 | ${TEE} ${FILE_LOG}
